@@ -1,7 +1,7 @@
 #'
 #'
 #'
-#' Checks number is luhn compliant
+#' Checks number is Luhn compliant
 #' @export
 #' @param number The number to be checked
 #' @examples
@@ -25,15 +25,16 @@ checkLuhn <- function(number) {
   digits <- unlist(strsplit(number, ""))
   digits <- digits[length(digits):1]
 
-  digits[seq(2, length(digits),2 )] <- as.numeric(digits[seq(2, length(digits),2 )]) * 2
+  to_replace <- seq(2, length(digits), 2)
+  digits[to_replace] <- as.numeric(digits[to_replace]) * 2
 
   # gonna do some maths, let's convert it to numbers
   digits <- as.numeric(digits)
 
-  # a digit cannot be two digits, so any that are greater than 9, subtract 9 and make the
-  # world a better place
+  # a digit cannot be two digits, so any that are greater than 9, subtract 9 and
+  # make the world a better place
   digits <- ifelse(digits > 9, digits - 9, digits)
 
   # does the sum divide by 10?
-  sum(digits) %% 10 == 0
+  ((sum(digits) %% 10) == 0)
 }
